@@ -9,7 +9,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-08'; # DATE
 our $DIST = 'Number-Util-Range'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our @EXPORT_OK = qw(convert_number_sequence_to_range);
 our %SPEC;
@@ -121,7 +121,9 @@ sub convert_number_sequence_to_range {
     my %args = @_;
 
     my $array = $args{array};
-    my $min_range_len = $args{min_range_len} // 4;
+    my $min_range_len = $args{min_range_len}
+        // $args{threshold} # old name, DEPRECATED
+        // 4;
     my $max_range_len = $args{max_range_len};
     my $separator = $args{separator} // '..';
     my $ignore_duplicates = $args{ignore_duplicates};
@@ -177,7 +179,7 @@ Number::Util::Range - Find sequences in number arrays & convert to range (e.g. 1
 
 =head1 VERSION
 
-This document describes version 0.004 of Number::Util::Range (from Perl distribution Number-Util-Range), released on 2023-09-08.
+This document describes version 0.005 of Number::Util::Range (from Perl distribution Number-Util-Range), released on 2023-09-08.
 
 =head1 FUNCTIONS
 
